@@ -394,8 +394,10 @@ class DisassembleCommand(CommandBase):
             'nargs': [1, 2, 3],
             'usage': "[-c/--center] ADDR [LEN]",
             'help': "Disassemble instructions at an address.",
-            'extra_help': "Only available if the capstone library is installed. To install "
-                           "capstone, run 'pip install capstone'.",
+            'extra_help':
+                "The length argument is in bytes and is optional, with a default of 6. If the -c option "
+                "is used, the disassembly is centered on the given address. Otherwise the disassembly "
+                "begins at the given address.",
             }
 
     def parse(self, args):
@@ -834,15 +836,22 @@ class FindCommand(CommandBase):
             'group': 'standard',
             'category': 'memory',
             'nargs': '*',
-            'usage': "ADDR LEN BYTE+",
+            'usage': "[-n] ADDR LEN BYTE+",
             'help': "Search for a value in memory within the given address range.",
             'extra_help': "A pattern of any number of bytes can be searched for. Each BYTE "
-                           "parameter must be an 8-bit value.",
+                           "parameter must be an 8-bit value. If the -n argument is passed, "
+                           "the search is negated and looks for the first set of bytes that "
+                           "does not match the provided values.",
             }
 
     def parse(self, args):
         if len(args) < 3:
             raise exceptions.CommandError("missing argument")
+        if args[0] == '-n':
+            self.negate = True
+            args.pop(0)
+        else:
+            self.negate = False
         self.addr = self._convert_value(args[0])
         self.length = self._convert_value(args[1])
         self.pattern = bytearray()
@@ -868,7 +877,7 @@ class FindCommand(CommandBase):
             data = bytearray(self.context.selected_ap.read_memory_block8(addr, chunk_size))
 
             offset = data.find(self.pattern)
-            if offset != -1:
+            if (offset != -1) ^ self.negate:
                 match = True
                 self.context.writei("Found pattern at address 0x%08x", addr + offset)
                 break
@@ -1115,20 +1124,44 @@ class RemoveWatchpointCommand(CommandBase):
             'names': ['rmwatch'],
             'group': 'standard',
             'category': 'breakpoints',
-            'nargs': 1,
-            'usage': "ADDR",
-            'help': "Remove a watchpoint.",
+            'nargs': [1, 2, 3],
+            'usage': "ADDR [r|w|rw] [1|2|4]",
+            'help': "Remove watchpoint(s).",
+            'extra_help':
+                    "Access type and size are optional. All watchpoints matching the specified parameters "
+                    "will be removed."
             }
 
     def parse(self, args):
         self.addr = self._convert_value(args[0])
+        if len(args) > 1:
+            try:
+                self.wptype = WATCHPOINT_FUNCTION_NAME_MAP[args[1]]
+            except KeyError:
+                raise exceptions.CommandError(f"unsupported watchpoint type '{args[1]}'")
+        else:
+            self.wptype = None
+        if len(args) > 2:
+            self.sz = self._convert_value(args[2])
+            if self.sz not in (1, 2, 4):
+                raise exceptions.CommandError(f"unsupported watchpoint size ({self.sz})")
+        else:
+            self.sz = None
 
     def execute(self):
         if self.context.selected_core.dwt is None:
             raise exceptions.CommandError("DWT not present")
         try:
-            self.context.selected_core.remove_watchpoint(self.addr)
-            self.context.writei("Removed watchpoint at 0x%08x", self.addr)
+            self.context.selected_core.remove_watchpoint(self.addr, self.size, self.wptype)
+            if self.size is not None:
+                wp_desc = f" ({self.size} bytes"
+                if self.wptype is not None:
+                    type_name = WATCHPOINT_FUNCTION_NAME_MAP[self.wptype]
+                    wp_desc += f", {type_name}"
+                wp_desc += ")"
+            else:
+                wp_desc = ""
+            self.context.write(f"Removed watchpoint(s) at {self.addr:#010x}{wp_desc}")
         except Exception:
             self.context.writei("Failed to remove watchpoint at 0x%08x", self.addr)
 
